#!/bin/sh -eu

. XML.sh
. TAP.sh

TAP
the=$( mktemp -d )
the=/tmp

get() {
	desc="$1"
	echo -n "$2" > $the/expected
	shift 2; ("$@") > $the/got
	set $the/got $the/expected
	cmp "$@" || {
		grep . "$@" | sed 's/^/# /'
		false
	}
	ok "$desc"
}

assert() {
	"$@" ; ok "success: $*"
}

# basic usecases of xml are tested de facto
# from the usage of WEB.sh in the next tests
# so here we test the advanced cases

assert __xml__ nodes div love=hate war=peace p
get 'change node name (without XMLNS)' \
	'<peace on="drugs">is lost</peace>' \
   	war 'on drugs' % is lost
assert __xml__ leaves input=output
get 'change leaf name (without XMLNS)' \
	'<output into="stderr" required/>' \
	input 'into stderr' required

XMLNS=orwell assert __xml__ nodes love=hate war=peace
get 'change node name (with the good XMLNS)' \
	'<orwell:peace on="drugs">is lost</orwell:peace>' \
   	war 'on drugs' % is lost
XMLNS=orwell assert __xml__ leaves input=output
get 'change leaf name (with the good XMLNS)' \
	'<orwell:output into="stderr" required/>' \
	input 'into stderr' required

XMLNS=irish XMLPRX=o __xml__ nodes connor=brian brian=beer
get 'honor $XMLPRX' \
	'<irish:beer is="unbearbale">people are adorable</irish:beer>' \
	o_brian 'is unbearbale' % people are adorable


assert __xml__ nodes  p div h1 title
assert __xml__ leaves input

get '+ is for id (looks like #)' \
	'<p id="main"></p>' \
	p +main
get '. is for classes' \
	'<p class="main important"></p>' \
	p .'main important'
get '$ defer interpolation' \
	'<h1>$title</h1>' \
	h1 $ title
get 'strings are attributes, 1st word is the key' \
	'<input type="text"/>' \
	input 'type text'
get 'strings are attributes, barewords come with no space' \
	'<input required/>' \
	input required
get '$ impliciy refer to the name' \
	'<title>$title</title>' \
	title $
get '! defer evaluation'     \
	'<div>$(hostname)</div>' \
	div ! hostname
get '% for text' \
	'<p>magick</p>' \
	p % magick
get '%% for CDATA' \
	'<p><![CDATA[<<+>>]]></p>' \
	p %% '<<+>>'
get '%$ for interpolation in CDATA' \
	'<p><![CDATA[$weird]]></p>' \
	p %$ weird
get 'put + . % together' \
	'<div id="main" class="container important">how cool is it?</div>' \
	div +main .'container important' % how cool is it\?





